@@ -1,14 +1,14 @@
 package Dist::Zilla::Plugin::PurePerlTests;
-# git description: 774b4f7
 
-$Dist::Zilla::Plugin::PurePerlTests::VERSION = '0.04';
 use strict;
 use warnings;
+use namespace::autoclean;
+
+our $VERSION = '0.05';
 
 use Dist::Zilla::File::InMemory;
 
 use Moose;
-use Moose::Autobox;
 
 with 'Dist::Zilla::Role::FileGatherer';
 
@@ -21,8 +21,8 @@ has env_var => (
 sub gather_files {
     my $self = shift;
 
-    for my $file ( grep { $_->name() =~ m<\At/.+\.t\z> }
-        $self->zilla()->files()->flatten() ) {
+    for my $file ( grep { $_->name() =~ m{\At/.+\.t\z} }
+        @{ $self->zilla()->files() } ) {
 
         next if $file->isa('Dist::Zilla::File::InMemory');
 
@@ -90,7 +90,7 @@ Dist::Zilla::Plugin::PurePerlTests - Run all your tests twice, once with XS code
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -154,7 +154,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 - 2014 by Dave Rolsky.
+This software is Copyright (c) 2010 - 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
